@@ -258,7 +258,7 @@ class FakeHTTPClient(base_client.HTTPClient):
                 },
                 "flavor": {
                     "id": 1,
-                    "name": "256 MB Server",
+                    "name": "256 mb server",
                 },
                 "hostId": "e4d909c290d0fb1ca068ffaddf22cbd0",
                 "status": "BUILD",
@@ -299,7 +299,7 @@ class FakeHTTPClient(base_client.HTTPClient):
                 },
                 "flavor": {
                     "id": 1,
-                    "name": "256 MB Server",
+                    "name": "256 mb server",
                 },
                 "hostId": "9e107d9d372bb6826bd81d3542a419d6",
                 "status": "ACTIVE",
@@ -340,7 +340,7 @@ class FakeHTTPClient(base_client.HTTPClient):
                 "image": "",
                 "flavor": {
                     "id": 1,
-                    "name": "256 MB Server",
+                    "name": "256 mb server",
                 },
                 "hostId": "9e107d9d372bb6826bd81d3542a419d6",
                 "status": "ACTIVE",
@@ -542,48 +542,73 @@ class FakeHTTPClient(base_client.HTTPClient):
     # Server actions
     #
 
+    none_actions = ['revertResize', 'migrate', 'os-stop', 'os-start',
+                    'forceDelete', 'restore', 'pause', 'unpause', 'unlock',
+                    'unrescue', 'resume', 'suspend', 'lock', 'shelve',
+                    'shelveOffload', 'unshelve', 'resetNetwork']
+    type_actions = ['os-getVNCConsole', 'os-getSPICEConsole',
+                    'os-getRDPConsole']
+
+    @classmethod
+    def check_server_actions(cls, body):
+        action = list(body)[0]
+        if action == 'reboot':
+            assert list(body[action]) == ['type']
+            assert body[action]['type'] in ['HARD', 'SOFT']
+        elif action == 'resize':
+            assert 'flavorRef' in body[action]
+        elif action in cls.none_actions:
+            assert body[action] is None
+        elif action == 'addFixedIp':
+            assert list(body[action]) == ['networkId']
+        elif action in ['removeFixedIp', 'removeFloatingIp']:
+            assert list(body[action]) == ['address']
+        elif action == 'addFloatingIp':
+            assert (list(body[action]) == ['address'] or
+                    sorted(list(body[action])) == ['address', 'fixed_address'])
+        elif action == 'changePassword':
+            assert list(body[action]) == ['adminPass']
+        elif action in cls.type_actions:
+            assert list(body[action]) == ['type']
+        elif action == 'os-migrateLive':
+            assert set(body[action].keys()) == set(['host', 'block_migration',
+                                                    'disk_over_commit'])
+        elif action == 'os-resetState':
+            assert list(body[action]) == ['state']
+        elif action == 'resetNetwork':
+            assert body[action] is None
+        elif action in ['addSecurityGroup', 'removeSecurityGroup']:
+            assert list(body[action]) == ['name']
+        elif action == 'createBackup':
+            assert set(body[action]) == set(['name', 'backup_type',
+                                             'rotation'])
+        else:
+            return False
+        return True
+
     def post_servers_1234_action(self, body, **kw):
         _headers = None
         _body = None
         resp = 202
         assert len(body.keys()) == 1
         action = list(body)[0]
-        if action == 'reboot':
-            assert list(body[action]) == ['type']
-            assert body[action]['type'] in ['HARD', 'SOFT']
+
+        if self.check_server_actions(body):
+            # NOTE(snikitin): No need to do any operations here. This 'pass'
+            # is needed to avoid AssertionError in the last 'else' statement
+            # if we found 'action' in method check_server_actions and
+            # raise AssertionError if we didn't find 'action' at all.
+            pass
         elif action == 'rebuild':
             body = body[action]
             adminPass = body.get('adminPass', 'randompassword')
             assert 'imageRef' in body
             _body = self.get_servers_1234()[2]
             _body['server']['adminPass'] = adminPass
-        elif action == 'resize':
-            keys = body[action].keys()
-            assert 'flavorRef' in keys
         elif action == 'confirmResize':
             assert body[action] is None
             # This one method returns a different response code
             return (204, {}, None)
-        elif action == 'revertResize':
-            assert body[action] is None
-        elif action == 'migrate':
-            assert body[action] is None
-        elif action == 'os-stop':
-            assert body[action] is None
-        elif action == 'os-start':
-            assert body[action] is None
-        elif action == 'forceDelete':
-            assert body[action] is None
-        elif action == 'restore':
-            assert body[action] is None
-        elif action == 'pause':
-            assert body[action] is None
-        elif action == 'unpause':
-            assert body[action] is None
-        elif action == 'lock':
-            assert body[action] is None
-        elif action == 'unlock':
-            assert body[action] is None
         elif action == 'rescue':
             if body[action]:
                 keys = set(body[action].keys())
@@ -591,62 +616,12 @@ class FakeHTTPClient(base_client.HTTPClient):
             else:
                 assert body[action] is None
             _body = {'adminPass': 'RescuePassword'}
-        elif action == 'unrescue':
-            assert body[action] is None
-        elif action == 'resume':
-            assert body[action] is None
-        elif action == 'suspend':
-            assert body[action] is None
-        elif action == 'lock':
-            assert body[action] is None
-        elif action == 'unlock':
-            assert body[action] is None
-        elif action == 'shelve':
-            assert body[action] is None
-        elif action == 'shelveOffload':
-            assert body[action] is None
-        elif action == 'unshelve':
-            assert body[action] is None
-        elif action == 'addFixedIp':
-            assert list(body[action]) == ['networkId']
-        elif action == 'removeFixedIp':
-            assert list(body[action]) == ['address']
-        elif action == 'addFloatingIp':
-            assert (list(body[action]) == ['address'] or
-                    sorted(list(body[action])) == ['address',
-                                                   'fixed_address'])
-        elif action == 'removeFloatingIp':
-            assert list(body[action]) == ['address']
         elif action == 'createImage':
             assert set(body[action].keys()) == set(['name', 'metadata'])
             _headers = dict(location="http://blah/images/456")
-        elif action == 'changePassword':
-            assert list(body[action]) == ['adminPass']
         elif action == 'os-getConsoleOutput':
             assert list(body[action]) == ['length']
             return (202, {}, {'output': 'foo'})
-        elif action == 'os-getVNCConsole':
-            assert list(body[action]) == ['type']
-        elif action == 'os-getSPICEConsole':
-            assert list(body[action]) == ['type']
-        elif action == 'os-getRDPConsole':
-            assert list(body[action]) == ['type']
-        elif action == 'os-migrateLive':
-            assert set(body[action].keys()) == set(['host',
-                                                    'block_migration',
-                                                    'disk_over_commit'])
-        elif action == 'os-resetState':
-            assert list(body[action]) == ['state']
-        elif action == 'resetNetwork':
-            assert body[action] is None
-        elif action == 'addSecurityGroup':
-            assert list(body[action]) == ['name']
-        elif action == 'removeSecurityGroup':
-            assert list(body[action]) == ['name']
-        elif action == 'createBackup':
-            assert set(body[action]) == set(['name',
-                                             'backup_type',
-                                             'rotation'])
         elif action == 'evacuate':
             keys = list(body[action])
             if 'adminPass' in keys:
@@ -697,19 +672,19 @@ class FakeHTTPClient(base_client.HTTPClient):
 
     def get_flavors_detail(self, **kw):
         flavors = {'flavors': [
-            {'id': 1, 'name': '256 MB Server', 'ram': 256, 'disk': 10,
+            {'id': 1, 'name': '256 mb server', 'ram': 256, 'disk': 10,
              'OS-FLV-EXT-DATA:ephemeral': 10,
              'os-flavor-access:is_public': True,
              'links': {}},
-            {'id': 2, 'name': '512 MB Server', 'ram': 512, 'disk': 20,
+            {'id': 2, 'name': '512 mb server', 'ram': 512, 'disk': 20,
              'OS-FLV-EXT-DATA:ephemeral': 20,
              'os-flavor-access:is_public': False,
              'links': {}},
-            {'id': 4, 'name': '1024 MB Server', 'ram': 1024, 'disk': 10,
+            {'id': 4, 'name': '1024 mb server', 'ram': 1024, 'disk': 10,
              'OS-FLV-EXT-DATA:ephemeral': 10,
              'os-flavor-access:is_public': True,
              'links': {}},
-            {'id': 'aa1', 'name': '128 MB Server', 'ram': 128, 'disk': 0,
+            {'id': 'aa1', 'name': '128 mb server', 'ram': 128, 'disk': 0,
              'OS-FLV-EXT-DATA:ephemeral': 0,
              'os-flavor-access:is_public': True,
              'links': {}}
@@ -761,16 +736,16 @@ class FakeHTTPClient(base_client.HTTPClient):
             {},
             {'flavor': {
                 'id': 3,
-                'name': '256 MB Server',
+                'name': '256 mb server',
                 'ram': 256,
                 'disk': 10,
             }},
         )
 
-    def get_flavors_512_MB_Server(self, **kw):
+    def get_flavors_512_mb_server(self, **kw):
         raise exceptions.NotFound('404')
 
-    def get_flavors_128_MB_Server(self, **kw):
+    def get_flavors_128_mb_server(self, **kw):
         raise exceptions.NotFound('404')
 
     def get_flavors_aa1(self, **kw):
@@ -2221,6 +2196,7 @@ class FakeSessionMockClient(base_client.SessionClient, FakeHTTPClient):
         self.callstack = []
         self.auth = mock.Mock()
         self.session = mock.Mock()
+        self.service_type = 'service_type'
 
         self.auth.get_auth_ref.return_value.project_id = 'tenant_id'
 
